==> xulrunner-10.0a1.en-US.win32.zip: jsloader/resource/gre/components/nsXULAppInstall.js <==
       )   resource:///components/nsXULAppInstall.js           X  A                                '           	 
       
       ;  5  = : Q;  5 5  Q;  5 5  Q;  5 5  Q;  5 5  Q;  5 5 	 	Q;  5 5 
 
Q;  5 5  Q    Q 
Q  Q  ; Y @]  }]  ] \6 Q ; Y @]  }]  	]  
] \6 Q  ; Y ;   = : ] ;  Z  >; 
^\: ]  
] \6 Q;  Z  >; ^\:  QŸϸ6׸ ccfcc3cc3cc3cc3cc3cc3cc3  46222:?GIKNȸX`\^cehȸ  `!  cf	c``3 氰c`3            Jb۬ӷe `              F  
   C o m p o n e n t s    u t i l s      i m p o r t %   r e s o u r c e : / / g r e / m o d u l e s / X P C O M U t i l s . j s m      n s I F i l e   
   i n t e r f a c e s    n s I I N I P a r s e r    n s I I N I P a r s e r F a c t o r y      n s I L o c a l F i l e    n s I S u p p o r t s      n s I X U L A p p I n s t a l l    n s I Z i p R e a d e r 	   P R _ W R O N L Y      P R _ C R E A T E _ F I L E    P R _ T R U N C A T E      d i r e c t o r y E x t r a c t o r 	   p r o t o t y p e   
   m I N I P a r s e r 	   i n i P a r s e r      c o p y T o    z i p E x t r a c t o r    _ i n s t a l l Z i p E n t r y 
   A p p I n s t a l l    I D &   { 0 0 7 9 0 a 1 9 - 2 7 e 2 - 4 d 9 a - b e f 0 - 2 4 4 0 8 0 f e a b f d }    c l a s s I D   
   X P C O M U t i l s 
   g e n e r a t e Q I    Q u e r y I n t e r f a c e    i n s t a l l A p p l i c a t i o n    N S G e t F a c t o r y    g e n e r a t e N S G e t F a c t o r y           g e t D i r e c t o r y K e y                  a K e y B          	   !                            ;  5 5  ;  5 5 :  T  ; :    v  = T  p       ccc	ccccf!\ Ƞ]{            Jb۬ӷe `              F  
   C o m p o n e n t s    c l a s s e s   %   @ m o z i l l a . o r g / f i l e / d i r e c t o r y _ s e r v i c e ; 1   
   g e t S e r v i c e 
   i n t e r f a c e s 
   n s I P r o p e r t i e s      g e t      n s I F i l e   #   C o u l n ' t   g e t   d i r e c t o r y   s e r v i c e   k e y :              e          (             c r e a t e I N I P a r s e r                  a F i l e                                              ;  5  = ; :  T  :    ccccc          Jb۬ӷe `              F  
   C o m p o n e n t s    m a n a g e r      g e t C l a s s O b j e c t B y C o n t r a c t I D '   @ m o z i l l a . o r g / x p c o m / i n i - p a r s e r - f a c t o r y ; 1      n s I I N I P a r s e r F a c t o r y      c r e a t e I N I P a r s e r             c o p y _ r e c u r s e               a S o u r c e      a D e s t      e      f      l e a f    d d e s t            
   Z                              T  5  W  Q m  V   :   ; : W QV 5 W QT  :  W QV  V : QV  :   9 V V : Q +V  	:   V  
B: QV  T V : QV   :  v c3 #  # #ccc	f3 c3 'cc3 cf	*cc `	ȸ-cccd1c`#cc3            Jb۬ӷe `              F     d i r e c t o r y E n t r i e s    g e t N e x t      Q u e r y I n t e r f a c e    n s I F i l e      l e a f N a m e    c l o n e      a p p e n d    i s D i r e c t o r y      c o p y _ r e c u r s e    e x i s t s    r e m o v e    c o p y T o    h a s M o r e E l e m e n t s             o p e n F i l e O u t p u t S t r e a m               a F i l e      s   =         
                          
       ;  5 5  ;  5 5 : W  QV   T  ; ; ; 	X>: QV     ccc	ccc3 c` :        Jb۬ӷe `              F  
   C o m p o n e n t s    c l a s s e s   )   @ m o z i l l a . o r g / n e t w o r k / f i l e - o u t p u t - s t r e a m ; 1      c r e a t e I n s t a n c e 
   i n t e r f a c e s    n s I F i l e O u t p u t S t r e a m      i n i t 	   P R _ W R O N L Y      P R _ C R E A T E _ F I L E    P R _ T R U N C A T E             d i r e c t o r y E x t r a c t o r                a F i l e   	                                            AT  6  Q   d G        Jb۬ӷe `              F   
   m D i r e c t o r y                         i n i F i l e   7                                   	       A5    ,A5  :  W  QV   = : QA9 V  : 6  QA5   aacc3 cf	Sgc
Ua    N        Jb۬ӷe `              F  ,
   m I N I P a r s e r 
   m D i r e c t o r y    c l o n e      a p p e n d    a p p l i c a t i o n . i n i      c r e a t e I N I P a r s e r          	   d e _ c o p y T o                 a D e s t                                              9  A5 T  : Q Zdf
  X        Jb۬ӷe `              F     c o p y _ r e c u r s e 
   m D i r e c t o r y           z i p E x t r a c t o r                a F i l e   2                                           A; 5 5  ; : 6  QA5   T  : QA5   @: Q  dcc	ccacf
acd  ^        Jb۬ӷe `              F  <
   m Z i p R e a d e r 
   C o m p o n e n t s    c l a s s e s       @ m o z i l l a . o r g / l i b j a r / z i p - r e a d e r ; 1    c r e a t e I n s t a n c e    n s I Z i p R e a d e r    o p e n    t e s t                         f               T                            A5    9 = : W  QV   = : QV   ; 5 X: QA5  	= V  : QA9 
V  : 6  Q 5  v V   :  Q  v     V p     V   :  Q  v     A5    akf3 cf	cffoac`
gc
\ scc\ w]{y]{{cc\ ~]{a h        Jb۬ӷe `              F  
   m I N I P a r s e r    g e t D i r e c t o r y K e y      T m p D    a p p e n d    a p p l i c a t i o n . i n i      c r e a t e U n i q u e    n s I F i l e      N O R M A L _ F I L E _ T Y P E 
   m Z i p R e a d e r    e x t r a c t      c r e a t e I N I P a r s e r      r e m o v e          e               e e          e          
       6   "      `   
          	   z e _ C o p y T o                a D e s t      e n t r i e s   	   e n t r y N a m e   A            0                       
       A5   @: W  Q %m  V   :  W QA A5  V T  : QV   :     acd3  .#+ cc3 ad` cc          Jb۬ӷe `              F  
   m Z i p R e a d e r    f i n d E n t r i e s      g e t N e x t      _ i n s t a l l Z i p E n t r y    h a s M o r e             z e _ i n s t a l l Z i p E n t r y           
   a Z i p R e a d e r 	   a Z i p E n t r y      a D e s t i n a t i o n    f i l e    d i r s    i s D i r e c t o r y      e n d      i            
   f                             T   :  W  QT    : W Q  T : W QV  W QV   f Q>W Q ;m  V   V V 7: QV   :    V   ; 5 X: Qe QV V V   $V   V V 7: QT   	T V  : Q   cc3 cf	3 cf	3 c3 1 ;7B$? c`a
cccff   ʸ c`a
c`      	     Jb۬ӷe `              F     c l o n e      s p l i t      t e s t    l e n g t h    a p p e n d    e x i s t s    c r e a t e    n s I F i l e      D I R E C T O R Y _ T Y P E    e x t r a c t      \ /        \ / $                 c r e a t e E x t r a c t o r                  a F i l e   #                                           T    :   ; T  R ; T  R  ccgg           Jb۬ӷe `              F      i s D i r e c t o r y      d i r e c t o r y E x t r a c t o r    z i p E x t r a c t o r        
   A p p I n s t a l l                                                                         Jb۬ӷe `              F            a i _ I A                a A p p F i l e 
   a D i r e c t o r y 	   a L e a f N a m e   	   e x t r a c t o r   	   i n i P a r s e r      a p p N a m e      v e n d o r    x u l r u n n e r B i n a r y   .                                %       9  T  : W  QV  5 W QV  = = : W QV QV  = = : W Q   v      T @ '9 = : U QV  T  V : Q T  	:  U QT  
:    T  ; 5 
X: QT =  
V U QT  T : QT  
:    T  ; 5 
X: QV   T : Q9 = : W QV  = : QV  T V  :  = : Q  f3 c3 c`3 0 c`_ ]{# fcf	Ȱcccccff cf	cccff cf	f3 cf	c`cg           Jb۬ӷe `              F     c r e a t e E x t r a c t o r   	   i n i P a r s e r   	   g e t S t r i n g      A p p      N a m e    V e n d o r    g e t D i r e c t o r y K e y      P r o g F      a p p e n d    c l o n e      e x i s t s    c r e a t e    n s I F i l e      D I R E C T O R Y _ T Y P E        c o p y T o    G r e D    x u l r u n n e r - s t u b . e x e    t o L o w e r C a s e      . e x e          e       /      

==> xulrunner-11.0a1.en-US.win32.zip: jsloader/resource/gre/components/nsXULAppInstall.js <==
   |s    )   resource:///components/nsXULAppInstall.js           X  A                                '           	 
       
       ;  5  = : Q;  5 5  Q;  5 5  Q;  5 5  Q;  5 5  Q;  5 5 	 	Q;  5 5 
 
Q;  5 5  Q    Q 
Q  Q  ; Y @]  }]  ] \6 Q ; Y @]  }]  	]  
] \6 Q  ; Y ;   = : ] ;  Z  >; 
^\: ]  
] \6 Q;  Z  >; ^\:  Qøϸ6׸ ccfcc3cc3cc3cc3cc3cc3cc3  46222:?GIKNȸX`\^cehȸ  `!  cf	c``3 氰c`3            Jb۬ӷe `              F  
   C o m p o n e n t s    u t i l s      i m p o r t %   r e s o u r c e : / / g r e / m o d u l e s / X P C O M U t i l s . j s m      n s I F i l e   
   i n t e r f a c e s    n s I I N I P a r s e r    n s I I N I P a r s e r F a c t o r y      n s I L o c a l F i l e    n s I S u p p o r t s      n s I X U L A p p I n s t a l l    n s I Z i p R e a d e r 	   P R _ W R O N L Y      P R _ C R E A T E _ F I L E    P R _ T R U N C A T E      d i r e c t o r y E x t r a c t o r 	   p r o t o t y p e   
   m I N I P a r s e r 	   i n i P a r s e r      c o p y T o    z i p E x t r a c t o r    _ i n s t a l l Z i p E n t r y 
   A p p I n s t a l l    I D &   { 0 0 7 9 0 a 1 9 - 2 7 e 2 - 4 d 9 a - b e f 0 - 2 4 4 0 8 0 f e a b f d }    c l a s s I D   
   X P C O M U t i l s 
   g e n e r a t e Q I    Q u e r y I n t e r f a c e    i n s t a l l A p p l i c a t i o n    N S G e t F a c t o r y    g e n e r a t e N S G e t F a c t o r y           g e t D i r e c t o r y K e y                  a K e y B          	   !                            ;  5 5  ;  5 5 :  T  ; :    v  = T  p       ccc	ccccf!\ Ƞ]{            Jb۬ӷe `              F  
   C o m p o n e n t s    c l a s s e s   %   @ m o z i l l a . o r g / f i l e / d i r e c t o r y _ s e r v i c e ; 1   
   g e t S e r v i c e 
   i n t e r f a c e s 
   n s I P r o p e r t i e s      g e t      n s I F i l e   #   C o u l n ' t   g e t   d i r e c t o r y   s e r v i c e   k e y :              e          (             c r e a t e I N I P a r s e r                  a F i l e                                              ;  5  = ; :  T  :    ccccc          Jb۬ӷe `              F  
   C o m p o n e n t s    m a n a g e r      g e t C l a s s O b j e c t B y C o n t r a c t I D '   @ m o z i l l a . o r g / x p c o m / i n i - p a r s e r - f a c t o r y ; 1      n s I I N I P a r s e r F a c t o r y      c r e a t e I N I P a r s e r             c o p y _ r e c u r s e               a S o u r c e      a D e s t      e      f      l e a f    d d e s t            
   Z                              T  5  W  Q m  V   :   ; : W QV 5 W QT  :  W QV  V : QV  :   9 V V : Q +V  	:   V  
B: QV  T V : QV   :  v c3 #  # #ccc	f3 c3 'cc3 cf	*cc `	ȸ-cccd1c`#cc3            Jb۬ӷe `              F     d i r e c t o r y E n t r i e s    g e t N e x t      Q u e r y I n t e r f a c e    n s I F i l e      l e a f N a m e    c l o n e      a p p e n d    i s D i r e c t o r y      c o p y _ r e c u r s e    e x i s t s    r e m o v e    c o p y T o    h a s M o r e E l e m e n t s             o p e n F i l e O u t p u t S t r e a m               a F i l e      s   =         
                          
       ;  5 5  ;  5 5 : W  QV   T  ; ; ; 	X>: QV     ccc	ccc3 c` :        Jb۬ӷe `              F  
   C o m p o n e n t s    c l a s s e s   )   @ m o z i l l a . o r g / n e t w o r k / f i l e - o u t p u t - s t r e a m ; 1      c r e a t e I n s t a n c e 
   i n t e r f a c e s    n s I F i l e O u t p u t S t r e a m      i n i t 	   P R _ W R O N L Y      P R _ C R E A T E _ F I L E    P R _ T R U N C A T E             d i r e c t o r y E x t r a c t o r                a F i l e   	                                            AT  6  Q   d G        Jb۬ӷe `              F   
   m D i r e c t o r y                         i n i F i l e   7                                   	       A5    ,A5  :  W  QV   = : QA9 V  : 6  QA5   aacc3 cf	Sgc
Ua    N        Jb۬ӷe `              F  ,
   m I N I P a r s e r 
   m D i r e c t o r y    c l o n e      a p p e n d    a p p l i c a t i o n . i n i      c r e a t e I N I P a r s e r          	   d e _ c o p y T o                 a D e s t                                              9  A5 T  : Q Zdf
  X        Jb۬ӷe `              F     c o p y _ r e c u r s e 
   m D i r e c t o r y           z i p E x t r a c t o r                a F i l e   2                                           A; 5 5  ; : 6  QA5   T  : QA5   @: Q  dcc	ccacf
acd  ^        Jb۬ӷe `              F  <
   m Z i p R e a d e r 
   C o m p o n e n t s    c l a s s e s       @ m o z i l l a . o r g / l i b j a r / z i p - r e a d e r ; 1    c r e a t e I n s t a n c e    n s I Z i p R e a d e r    o p e n    t e s t                         f               T                            A5    9 = : W  QV   = : QV   ; 5 X: QA5  	= V  : QA9 
V  : 6  Q 5  v V   :  Q  v     V p     V   :  Q  v     A5    akf3 cf	cffoac`
gc
\ scc\ w]{y]{{cc\ ~]{a h        Jb۬ӷe `              F  
   m I N I P a r s e r    g e t D i r e c t o r y K e y      T m p D    a p p e n d    a p p l i c a t i o n . i n i      c r e a t e U n i q u e    n s I F i l e      N O R M A L _ F I L E _ T Y P E 
   m Z i p R e a d e r    e x t r a c t      c r e a t e I N I P a r s e r      r e m o v e          e               e e          e          
       6   "      `   
          	   z e _ C o p y T o                a D e s t      e n t r i e s   	   e n t r y N a m e   A            0                       
       A5   @: W  Q %m  V   :  W QA A5  V T  : QV   :     acd3  .#+ cc3 ad` cc          Jb۬ӷe `              F  
   m Z i p R e a d e r    f i n d E n t r i e s      g e t N e x t      _ i n s t a l l Z i p E n t r y    h a s M o r e             z e _ i n s t a l l Z i p E n t r y           
   a Z i p R e a d e r 	   a Z i p E n t r y      a D e s t i n a t i o n    f i l e    d i r s    i s D i r e c t o r y      e n d      i            
   f                             T   :  W  QT    : W Q  T : W QV  W QV   f Q>W Q ;m  V   V V 7: QV   :    V   ; 5 X: Qe QV V V   $V   V V 7: QT   	T V  : Q   cc3 cf	3 cf	3 c3 1 ;7B$? c`a
cccff   ʸ c`a
c`      	     Jb۬ӷe `              F     c l o n e      s p l i t      t e s t    l e n g t h    a p p e n d    e x i s t s    c r e a t e    n s I F i l e      D I R E C T O R Y _ T Y P E    e x t r a c t      \ /        \ / $                 c r e a t e E x t r a c t o r                  a F i l e   #                                           T    :   ; T  R ; T  R  ccgg           Jb۬ӷe `              F      i s D i r e c t o r y      d i r e c t o r y E x t r a c t o r    z i p E x t r a c t o r        
   A p p I n s t a l l                                                                         Jb۬ӷe `              F            a i _ I A                a A p p F i l e 
   a D i r e c t o r y 	   a L e a f N a m e   	   e x t r a c t o r   	   i n i P a r s e r      a p p N a m e      v e n d o r    x u l r u n n e r B i n a r y   .                                %       9  T  : W  QV  5 W QV  = = : W QV QV  = = : W Q   v      T @ '9 = : U QV  T  V : Q T  	:  U QT  
:    T  ; 5 
X: QT =  
V U QT  T : QT  
:    T  ; 5 
X: QV   T : Q9 = : W QV  = : QV  T V  :  = : Q  f3 c3 c`3 0 c`_ ]{# fcf	Ȱcccccff cf	cccff cf	f3 cf	c`cg           Jb۬ӷe `              F     c r e a t e E x t r a c t o r   	   i n i P a r s e r   	   g e t S t r i n g      A p p      N a m e    V e n d o r    g e t D i r e c t o r y K e y      P r o g F      a p p e n d    c l o n e      e x i s t s    c r e a t e    n s I F i l e      D I R E C T O R Y _ T Y P E        c o p y T o    G r e D    x u l r u n n e r - s t u b . e x e    t o L o w e r C a s e      . e x e          e       /      
